-- Daten testen
SELECT year(OrderDate)      AS [Year],
       COUNT(SalesOrderID)  AS Orders
  FROM AdventureWorks2014.Sales.SalesOrderHeader
 GROUP BY year(OrderDate)
 ORDER BY [Year]
 -- Ergebnis
 /*
 Year        Orders
----------- -----------
2011        1607
2012        3915
2013        14182
2014        11761
(4 row(s) affected)
 */
GO
-- DELETE FROM AW.Sales.SalesOrderHeader
-- Daten einspielen
INSERT INTO AW.Sales.SalesOrderHeader
  (OrderDate, CustomerID, TotalDue)
SELECT OrderDate, CustomerID, TotalDue 
  FROM AdventureWorks2014.Sales.SalesOrderHeader
-- Partitionen abrufen
SELECT r.value, f.*
  FROM sys.partition_functions AS f INNER JOIN sys.partition_range_values AS r
    ON f.function_id = r.function_id 
 WHERE f.name = 'pf_OrderYear'
 -- Ergebnis
 /*
value      name         function_id  type type_desc fanout 
---------- ------------ ------------ ---- --------- ------ 
2012-12-31 pf_OrderYear 65539        R    RANGE      4     
2013-12-31 pf_OrderYear 65539        R    RANGE      4     
2014-12-31 pf_OrderYear 65539        R    RANGE      4     
 */
-- Daten in Partitionen testen
WITH partitionCount AS (
 SELECT t.object_id, 
        t.name, 
		p.partition_id, 
		p.partition_number, 
		p.rows
   FROM sys.partitions AS p INNER JOIN sys.tables AS t
     ON  p.object_id = t.object_id
  WHERE p.partition_id IS NOT NULL AND t.name = 'SalesOrderHeader'
)
SELECT *, 
       SUM(rows) OVER (ORDER BY partition_id) AS Total 
  FROM partitionCount
 ORDER BY partition_number
GO
-- Ergebnis
/*
object_id   name             partition      partition rows   Total
                             _id            _number
----------- ---------------- -------------- ---------- ------ -----
501576825   SalesOrderHeader 7205759404...  1          5522   5522
501576825   SalesOrderHeader 7205759404...  2          14182  19704
501576825   SalesOrderHeader 7205759404...  3          11761  31465
501576825   SalesOrderHeader 7205759404...  4          0      31465
501576825   SalesOrderHeader 7205759404...  1          31465  62930
(5 row(s) affected)
*/

SELECT $partition.pf_OrderYear(so.OrderDate) AS [Partition Number],
       MIN(so.OrderDate)                     AS [Min Order Date],
       MAX(so.OrderDate)                     AS [Max Order Date],
       COUNT(*)                              AS [Rows In Partition]
  FROM Sales.SalesOrderHeader AS so
 GROUP BY $partition.pf_OrderYear(so.OrderDate)
 ORDER BY [Partition Number]
GO
-- Ergebnis
/*
Partition Number Min Order Date Max Order Date Rows In Partition
---------------- -------------- -------------- -----------------
1                2011-05-31     2012-12-31     5522
2                2013-01-01     2013-12-31     14182
3                2014-01-01     2014-06-30     11761
*/
-- Zahlen vergleichen
DELETE FROM Sales.SalesOrderHeader
 WHERE year(OrderDate) IN (2011, 2014)
GO
SELECT COUNT(*) FROM Sales.SalesOrderHeader