-- Daten testen
SELECT year(OrderDate)      AS [Year],
       COUNT(SalesOrderID)  AS Orders
  FROM AdventureWorks2014.Sales.SalesOrderHeader
 GROUP BY year(OrderDate)
 ORDER BY [Year]
 -- Ergebnis
 /*
 Year        Orders
----------- -----------
2011        1607
2012        3915
2013        14182
2014        11761
(4 row(s) affected)
 */
GO
-- DELETE FROM AW.Sales.SalesOrderHeader
-- Daten einspielen
INSERT INTO AW.Sales.SalesOrderHeader
  (OrderDate, CustomerID, TotalDue)
SELECT OrderDate, CustomerID, TotalDue 
  FROM AdventureWorks2014.Sales.SalesOrderHeader
-- Partitionen abrufen
SELECT r.value, f.*
  FROM sys.partition_functions AS f INNER JOIN sys.partition_range_values AS r
    ON f.function_id = r.function_id 
 WHERE f.name = 'pf_OrderYear'
 -- Ergebnis
 /*
value                                                                                                                                                                                                                                                            name                                                                                                                             function_id type type_desc                                                    fanout      boundary_value_on_right is_system create_date             modify_date
---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- -------------------------------------------------------------------------------------------------------------------------------- ----------- ---- ------------------------------------------------------------ ----------- ----------------------- --------- ----------------------- -----------------------
2011-12-31 00:00:00.000                                                                                                                                                                                                                                          pf_OrderYear                                                                                                                     65536       R    RANGE                                                        6           0                       0         2015-01-30 15:55:56.990 2015-01-30 15:55:56.990
2012-12-31 00:00:00.000                                                                                                                                                                                                                                          pf_OrderYear                                                                                                                     65536       R    RANGE                                                        6           0                       0         2015-01-30 15:55:56.990 2015-01-30 15:55:56.990
2013-12-31 00:00:00.000                                                                                                                                                                                                                                          pf_OrderYear                                                                                                                     65536       R    RANGE                                                        6           0                       0         2015-01-30 15:55:56.990 2015-01-30 15:55:56.990
2014-12-31 00:00:00.000                                                                                                                                                                                                                                          pf_OrderYear                                                                                                                     65536       R    RANGE                                                        6           0                       0         2015-01-30 15:55:56.990 2015-01-30 15:55:56.990
2015-12-31 00:00:00.000                                                                                                                                                                                                                                          pf_OrderYear                                                                                                                     65536       R    RANGE                                                        6           0                       0         2015-01-30 15:55:56.990 2015-01-30 15:55:56.990

(5 row(s) affected)

  
 */
-- Daten in Partitionen testen
WITH partitionCount AS (
 SELECT t.object_id, 
        t.name, 
		p.partition_id, 
		p.partition_number, 
		p.rows
   FROM sys.partitions AS p INNER JOIN sys.tables AS t
     ON  p.object_id = t.object_id
  WHERE p.partition_id IS NOT NULL AND t.name = 'SalesOrderHeader'
)
SELECT *, 
       SUM(rows) OVER (ORDER BY partition_id) AS Total 
  FROM partitionCount
 ORDER BY partition_number
GO
-- Ergebnis
/*
object_id   name             partition         partition  rows   Total
                             _id               _number
----------- ---------------- ----------------- ---------- ------ -----
261575970   SalesOrderHeader 72057594040549376 1          1607   1607
261575970   SalesOrderHeader 72057594040614912 2          3915   5522
261575970   SalesOrderHeader 72057594040680448 3          14182  19704
261575970   SalesOrderHeader 72057594040745984 4          11761  31465
261575970   SalesOrderHeader 72057594040811520 5          0      31465
261575970   SalesOrderHeader 72057594040877056 6          0      31465

(6 row(s) affected)
*/

