USE [AW-Tuning]
GO
-- Alle Indizes einer Tabelle
SELECT * 
  FROM sys.indexes
 WHERE object_id = OBJECT_ID('[Production].[Product]')

-- Fragmentierung von Indizes
SELECT DB_Name(database_id)         AS [DB Name],
       Object_Name(ips.object_id)   AS [Table Name],
	   ips.index_id                 AS [Index ID],
	   i.name                       AS [Index Name],
	   index_type_desc              AS [Type],
	   avg_fragmentation_in_percent AS Fragmentation,
	   avg_fragment_size_in_pages   AS [Avg pages in a fragment],
	   page_count                   AS [Pages in total],
	   record_count                 AS [Records in total]
  FROM sys.dm_db_index_physical_stats(0,0,-1,0, 'detailed') AS ips INNER JOIN sys.indexes AS i
    ON ips.object_id = i.object_id
 WHERE avg_fragmentation_in_percent > 0
   AND database_id  = DB_ID('AW-Tuning')
GO
-- Aktionen
WITH fragmentation AS (
SELECT a.index_id AS [Index-ID],
       name       AS [Index],
	   avg_fragmentation_in_percent AS [Fragmentation %]
  FROM sys.dm_db_index_physical_stats (DB_ID(N'AW-Tuning'), 
                                       OBJECT_ID(N'Production.Product'), 
									   NULL, NULL, NULL) AS a
       INNER JOIN sys.indexes AS b
    ON a.object_id = b.object_id
   AND a.index_id = b.index_id
)
SELECT *,
       CASE
	     WHEN [Fragmentation %] BETWEEN 5 AND 30
		  THEN 'REORGANIZE'
		 WHEN [Fragmentation %] > 30
		  THEN 'REBUILD'
		 ELSE '---'
	   END AS ToDo
  FROM fragmentation
GO
-- Ergebnis
/*
Index-ID    Index             Fragmenation %      ToDo
----------- ----------------- ------------------- -------------
1           ix_ProductNumber  25                  REORGANIZE
4           PK_Product        66.6666666666667    REBUILD
5           ix_ProductDetails 66.6666666666667    REBUILD

(3 row(s) affected)

*/



