-- Einfache Aggregate
SELECT c.CustomerID            AS Kunde,
       c.TerritoryID           AS Gebiet,
       YEAR(OrderDate)         AS Jahr,
       COUNT(soh.SalesOrderID) AS Bestellungen
  FROM Sales.Customer AS c INNER JOIN Sales.SalesOrderHeader AS soh
    ON c.CustomerID = soh.CustomerID
 GROUP BY c.CustomerID, c.TerritoryID, YEAR(OrderDate)
 ORDER BY Jahr, Gebiet, Bestellungen DESC

-- Ergebnis
/*
Kunde       Gebiet      Jahr        Bestellungen
----------- ----------- ----------- ------------
344         1           2001        2
218         1           2001        2
401         1           2001        2
73          1           2001        2
*/

-- Bildung von Wrfeln
SELECT c.CustomerID              AS Kunde,
       c.TerritoryID             AS Gebiet,
       YEAR(OrderDate)           AS Jahr,
       COUNT(soh.SalesOrderID)   AS [Best.],
       GROUPING(YEAR(OrderDate)) AS J,
       GROUPING(c.TerritoryID)   AS G,
       GROUPING(c.CustomerID)    AS K
  FROM Sales.Customer AS c INNER JOIN Sales.SalesOrderHeader AS soh
    ON c.CustomerID = soh.CustomerID
 WHERE c.TerritoryID <= 3
   AND YEAR(OrderDate) <= 2002
   AND c.CustomerID <= 5
 GROUP BY c.CustomerID, c.TerritoryID, YEAR(OrderDate)
         WITH CUBE
 ORDER BY Jahr, Gebiet, [Best.] DESC

-- Ergebnis
/*
Kunde       Gebiet      Jahr        Best.       J    G    K
----------- ----------- ----------- ----------- ---- ---- ----
NULL        NULL        NULL        6           1    1    1
1           NULL        NULL        4           1    1    0
2           NULL        NULL        2           1    1    0
NULL        1           NULL        6           1    0    1
1           1           NULL        4           1    0    0
2           1           NULL        2           1    0    0
1           NULL        2001        2           0    1    0
NULL        NULL        2001        2           0    1    1
NULL        1           2001        2           0    0    1
1           1           2001        2           0    0    0
NULL        NULL        2002        4           0    1    1
1           NULL        2002        2           0    1    0
2           NULL        2002        2           0    1    0
NULL        1           2002        4           0    0    1
1           1           2002        2           0    0    0
2           1           2002        2           0    0    0
(16 Zeile(n) betroffen)

*/