-- Gesamtaggregate mit Spaltenunterabfrage
SELECT SalesOrderID,
       (SELECT SUM(TotalDue)
          FROM Sales.SalesOrderHeader
         WHERE YEAR(OrderDate) < 2002
           AND TerritoryID < 3) AS Turnover,
       (SELECT MIN(TotalDue)
          FROM Sales.SalesOrderHeader
         WHERE YEAR(OrderDate) < 2002
           AND TerritoryID < 3) AS Min,
       (SELECT AVG(TotalDue)
          FROM Sales.SalesOrderHeader
         WHERE YEAR(OrderDate) < 2002
           AND TerritoryID < 3) AS Avg
  FROM Sales.SalesOrderHeader
 WHERE YEAR(OrderDate) < 2002
   AND TerritoryID < 3

-- Aggregate mit CTE
WITH Agg AS (
SELECT *
  FROM Sales.SalesOrderHeader
  WHERE YEAR(OrderDate) < 2002
    AND TerritoryID < 3
)
SELECT SalesOrderID,
       (SELECT SUM(TotalDue) FROM agg) AS Turnover,
       (SELECT MIN(TotalDue) FROM agg) AS Min,
       (SELECT AVG(TotalDue) FROM agg) AS Avg
  FROM Agg
 GROUP BY SalesOrderID

-- Aggregate mit OVER()
SELECT SalesOrderID,
       SUM(TotalDue) OVER() AS Turnover,
       MIN(TotalDue) OVER() AS Min,
       AVG(TotalDue) OVER() AS Avg,
       (TotalDue / SUM(TotalDue) OVER()) AS Schnitt  
  FROM Sales.SalesOrderHeader
WHERE YEAR(OrderDate) < 2002
  AND TerritoryID < 3

-- Ergebnis
/*
SalesOrderID Turnover       Min      Avg         Schnitt
------------ -------------- -------- ----------- --------- 
43664        3458314,9992   6,8234   15438,9062  0,0093
43665        3458314,9992   6,8234   15438,9062  0,0054
43669        3458314,9992   6,8234   15438,9062  0,0002
43671        3458314,9992   6,8234   15438,9062  0,0031
*/