-- Reihennummern ohne ROW_NUMBER()

-- Einfache Zhlung
SELECT SalesOrderID,
       TerritoryID,
       TotalDue,
       (SELECT COUNT(s2.SalesOrderID)
          FROM Sales.SalesOrderHeader AS s2
         WHERE s2.SalesOrderID <= s1.SalesOrderID) AS RN
  FROM Sales.SalesOrderHeader AS s1
WHERE s1.SalesOrderID < 43662

-- Ergebnis
/*
SalesOrderID TerritoryID TotalDue              RN
------------ ----------- --------------------- -----------
43659        5           27231,5495            1
43660        5           1716,1794             2
43661        6           43561,4424            3
(3 Zeile(n) betroffen)

*/

-- Partitionierung
SELECT TerritoryID,
       YEAR(OrderDate) AS [Year],
       SUM(TotalDue)   AS Turnover,
       (SELECT COUNT(DISTINCT s2.TerritoryID)
          FROM Sales.SalesOrderHeader AS s2
         WHERE s2.TerritoryID <= s1.TerritoryID
           AND s2.TerritoryID BETWEEN 5 AND 7) AS RN
  FROM Sales.SalesOrderHeader AS s1
WHERE TerritoryID BETWEEN 5 AND 7
GROUP BY TerritoryID, YEAR(OrderDate)
ORDER BY YEAR(OrderDate), s1.TerritoryID

-- Ergebnis
/*
TerritoryID Year        Turnover              RN
----------- ----------- --------------------- --------------------
7           2001        199531,723            1
5           2001        1928148,6139          2
6           2001        2173647,1453          3
7           2002        1717145,7439          1
5           2002        3814944,144           2
6           2002        7215430,5017          3
5           2003        3261402,9982          1
7           2003        4366078,3475          2
6           2003        8186021,9178          3
5           2004        1566084,6664          1
7           2004        2853948,6596          2
6           2004        3926712,8926          3
(12 Zeile(n) betroffen)
*/