-- Umstze pro Jahr
SELECT YEAR(OrderDate) AS [Year],
       SUM(TotalDue)   AS Total
  FROM Sales.SalesOrderHeader
 GROUP BY YEAR(OrderDate)

-- Ergebnis
/*
Year        Total
----------- ---------------------
2004        32196912,4165
2001        14327552,2263
2002        39875505,095
2003        54307615,0868
(4 Zeile(n) betroffen)
*/

SELECT DISTINCT
  (SELECT SUM(TotalDue)
     FROM Sales.SalesOrderHeader
    WHERE Year(OrderDate) = 2001) AS [2001],
  (SELECT SUM(TotalDue)
     FROM Sales.SalesOrderHeader
    WHERE Year(OrderDate) = 2002) AS [2002]
FROM Sales.SalesOrderHeader

-- Ergebnis
/*
2001                  2002
--------------------- ---------------------
14327552,2263         39875505,095
(1 Zeile(n) betroffen)
*/

SELECT CASE 
         WHEN YEAR(OrderDate) = 2001
         THEN SUM(TotalDue) ELSE NULL
       END AS [2001],
       CASE 
         WHEN YEAR(OrderDate) = 2002
         THEN SUM(TotalDue) ELSE NULL
       END AS [2002]
FROM Sales.SalesOrderHeader
GROUP BY YEAR(OrderDate)

-- Ergebnis
/*
2001                  2002
--------------------- ---------------------
NULL                  NULL
14327552,2263         NULL
NULL                  39875505,095
NULL                  NULL
(4 Zeile(n) betroffen)
*/

SELECT SUM(CASE YEAR(OrderDate)
            WHEN  2001 THEN TotalDue ELSE NULL
           END) AS [2001],
       SUM(CASE YEAR(OrderDate)
            WHEN 2002 THEN TotalDue ELSE NULL
           END) AS [2002]
FROM Sales.SalesOrderHeader

-- Ergebnis
/*
2001                  2002
--------------------- ---------------------
14327552,2263         39875505,095
Warnung: Ein NULL-Wert wird durch einen Aggregat- oder sonstigen SET-Vorgang gelscht.
(1 Zeile(n) betroffen
*/

SELECT SUM(CASE 
            WHEN YEAR(OrderDate) = 2001
            THEN TotalDue ELSE NULL
           END) AS [2001],
       SUM(CASE 
            WHEN YEAR(OrderDate) = 2002
            THEN TotalDue ELSE NULL
           END) AS [2002],
       SUM(CASE 
             WHEN YEAR(OrderDate) > 2002
             THEN TotalDue ELSE NULL
           END) AS [2002 until today]
FROM Sales.SalesOrderHeader

-- Ergebnis
/*
2001                  2002                  2002 until today
--------------------- --------------------- ---------------------
14327552,2263         39875505,095          86504527,5033
Warnung: Ein NULL-Wert wird durch einen Aggregat- oder sonstigen SET-Vorgang gelscht.
(1 Zeile(n) betroffen)
*/