-- DML-Trigger
USE AdventureWorks
GO
-- Triggerexistenz testen und ggf. lschen
IF OBJECT_ID ('Production.SafteyReminder', 'TR') IS NOT NULL
   DROP TRIGGER Production.SafteyReminder
GO
CREATE TRIGGER SafteyReminder
ON Production.Product2
INSTEAD OF INSERT AS
 -- Variablen 
 DECLARE @vSafetyStockLevel smallint,
         @vProductNumber    nvarchar(25),
         @vMessage          nvarchar(100)
 -- ... und Cursor fr mehrere Zeilen
 DECLARE cProducts CURSOR FAST_FORWARD FOR
  SELECT ProductNumber, SafetyStockLevel
    FROM inserted
 -- Verarbeitung
 -- Fall 1: Keine Zeile
 IF @@rowCount = 0 RETURN
 -- Fall 2: Nur eine Zeile
 IF @@rowCount = 1 BEGIN
  -- Sicherheitsbestand abrufen
  SELECT @vSafetyStockLevel = SafetyStockLevel
  FROM inserted
  -- Testen und Fehlermeldung ausgeben
  IF @vSafetyStockLevel <= 4 BEGIN
   SET @vMessage = 'Sicherheitsbestand: ' + ltrim(str(@vSafetyStockLevel)) + '. Mind. 4'
   RAISERROR (@vMessage, 16, 10) 
  END
  ELSE
   INSERT INTO Production.Product2
   SELECT * FROM inserted
 END
 -- Fall 3: Mehrere Zeilen
 ELSE BEGIN
   -- Sicherheitsbestand pro Zeile abrufen
   OPEN cProducts
   FETCH NEXT FROM cProducts
    INTO @vProductNumber, @vSafetyStockLevel
   WHILE @@fetch_status = 0 BEGIN
     -- Zeilenweise testen und Fehlermeldung ausgeben
     IF @vSafetyStockLevel <= 4 BEGIN
      SET @vMessage = 'Sicherheitsbestand: ' + ltrim(str(@vSafetyStockLevel)) + '. Mind. 4'
      RAISERROR (@vMessage, 16, 10) 
      END 
     ELSE BEGIN
      INSERT INTO Production.Product2
      SELECT *
        FROM inserted
       WHERE ProductNumber = @vProductNumber
     END
    FETCH NEXT FROM cProducts
    INTO @vProductNumber, @vSafetyStockLevel    
   END
   CLOSE cProducts
   DEALLOCATE cProducts
 END
GO

-- Testen
DELETE FROM Production.Product2
GO
INSERT INTO Production.Product2
VALUES ('ML Mountain Seat Assembly', 'SA-M237', 500, 108.99, 147.14)
GO
INSERT INTO Production.Product2
VALUES ('Sport-100 Helmet, Red', 'HL-U509-R', 4, 13.09, 34.99)
GO
INSERT INTO Production.Product2
SELECT Name, ProductNumber, SafetyStockLevel, StandardCost, ListPrice
  FROM Production.Product
 WHERE SafetyStockLevel >= 4
   AND ProductNumber NOT IN ('SA-M237', 'HL-U509-R')
GO