-- Testdaten bernehmen
DELETE FROM Production.ProductInventory2
GO
DELETE FROM Production.Product2
GO
INSERT INTO Production.Product2
SELECT Name, ProductNumber, SafetyStockLevel, StandardCost, ListPrice
  FROM Production.Product
GO
INSERT INTO Production.ProductInventory2
SELECT p1.ProductNumber, LocationID, Shelf, Bin, Quantity
  FROM Production.Product2 AS p2 INNER JOIN Production.Product AS p1
    ON p2.ProductNumber = p1.ProductNumber
       INNER JOIN Production.ProductInventory AS piv
    ON piv.ProductID = p1.ProductID
GO


-- Sicht erstellen
CREATE VIEW Production.vProductInventory AS
SELECT p2.ProductNumber, Name, SafetyStockLevel, StandardCost, ListPrice, SUM(Quantity) AS TotalQuantity
  FROM Production.Product2 AS p2 INNER JOIN Production.ProductInventory2 AS piv2
    ON p2.ProductNumber = piv2.ProductNumber
 GROUP BY p2.ProductNumber, Name, SafetyStockLevel, StandardCost, ListPrice
GO

-- Trigger fr Einfgeoperation
IF OBJECT_ID ('Production.trgInsertvProductInventory', 'TR') IS NOT NULL
   DROP TRIGGER Production.trgInsertvProductInventory
GO
CREATE TRIGGER Production.trgInsertvProductInventory
ON Production.vProductInventory
INSTEAD OF INSERT, UPDATE
AS
 -- Fall 1: Keine nderung
 IF @@rowcount = 0 RETURN
 -- Fall 2: Verbotene Aggregatspalte
 IF update(TotalQuantity) BEGIN
  RAISERROR('Aggregat TotalQuantity nicht aktualisierbar', 16, 1)
  ROLLBACK TRANSACTION
  RETURN
 END
 -- Fall 3: Erlaubte Spalte: ListPrice
 IF substring(columns_updated(),1,1) 
    & power(2,(5-1)) = power(2,(5-1)) BEGIN
  UPDATE Production.Product2
     SET ListPrice = i.ListPrice
    FROM Production.Product2 AS p2 INNER JOIN inserted AS i
      ON p2.ProductNumber = i.ProductNumber
 END
GO

-- Test
UPDATE Production.vProductInventory
   SET TotalQuantity = 100
 WHERE ProductNumber = 'BB-8107'
/*
Msg 50000, Level 16, State 1, Procedure trgInsertvProductInventory, Line 9
Aggregat TotalQuantity nicht aktualisierbar
Msg 3609, Level 16, State 1, Line 1
Die Transaktion endete mit dem Trigger. Der Batch wurde abgebrochen.
*/

--Eine Zeile
UPDATE Production.vProductInventory
   SET ListPrice = ListPrice*0.9
 WHERE ProductNumber = 'BB-8107'
GO
SELECT *
  FROM Production.vProductInventory
 WHERE ProductNumber = 'BB-8107'

-- Mehrere Zeilen
UPDATE Production.vProductInventory
   SET ListPrice = ListPrice*1.1
